Index: src/crankshaft/arm/lithium-codegen-arm.cc |
diff --git a/src/crankshaft/arm/lithium-codegen-arm.cc b/src/crankshaft/arm/lithium-codegen-arm.cc |
index 76d0a6817c911f669ff39592b6ecf895e45f18a9..e092a9e040c7ac2dce6b975542a83378a110671a 100644 |
--- a/src/crankshaft/arm/lithium-codegen-arm.cc |
+++ b/src/crankshaft/arm/lithium-codegen-arm.cc |
@@ -2870,11 +2870,11 @@ void LCodeGen::DoLoadKeyedFixedArray(LLoadKeyed* instr) { |
__ b(ne, &done); |
if (info()->IsStub()) { |
// A stub can safely convert the hole to undefined only if the array |
// protector cell contains (Smi) Isolate::kArrayProtectorValid. Otherwise |
// it needs to bail out. |
__ LoadRoot(result, Heap::kArrayProtectorRootIndex); |
__ ldr(result, FieldMemOperand(result, Cell::kValueOffset)); |
- __ cmp(result, Operand(Smi::FromInt(Isolate::kArrayProtectorValid))); |
+ __ cmp(result, Operand(Smi::FromInt(Isolate::kProtectorValid))); |
DeoptimizeIf(ne, instr, DeoptimizeReason::kHole); |
} |
__ LoadRoot(result, Heap::kUndefinedValueRootIndex); |
@@ -2870,11 +2870,11 @@ void LCodeGen::DoLoadKeyedFixedArray(LLoadKeyed* instr) { |
if (info()->IsStub()) { |
// A stub can safely convert the hole to undefined only if the array |
- // protector cell contains (Smi) Isolate::kArrayProtectorValid. Otherwise |
+ // protector cell contains (Smi) Isolate::kProtectorValid. Otherwise |
// it needs to bail out. |
__ LoadRoot(result, Heap::kArrayProtectorRootIndex); |